aboutsummaryrefslogtreecommitdiff
path: root/backends
diff options
context:
space:
mode:
authorPeter Bozsó2016-06-12 21:32:29 +0200
committerAlexander Tkachev2016-08-24 16:07:55 +0600
commit1403cf006c5ebfd4a6101b89f4ff1d8760bb0ea4 (patch)
tree736e760434ab906613dbb035fa0f9f4b40b5d948 /backends
parentc068b74f303484819a8432379890b637d7bba029 (diff)
downloadscummvm-rg350-1403cf006c5ebfd4a6101b89f4ff1d8760bb0ea4.tar.gz
scummvm-rg350-1403cf006c5ebfd4a6101b89f4ff1d8760bb0ea4.tar.bz2
scummvm-rg350-1403cf006c5ebfd4a6101b89f4ff1d8760bb0ea4.zip
CLOUD: Make enum StorageIDs' name singular
Diffstat (limited to 'backends')
-rw-r--r--backends/cloud/cloudmanager.cpp2
-rw-r--r--backends/cloud/cloudmanager.h6
2 files changed, 4 insertions, 4 deletions
diff --git a/backends/cloud/cloudmanager.cpp b/backends/cloud/cloudmanager.cpp
index 0c087be7be..4a87098f50 100644
--- a/backends/cloud/cloudmanager.cpp
+++ b/backends/cloud/cloudmanager.cpp
@@ -50,7 +50,7 @@ Common::String CloudManager::getStorageConfigName(uint32 index) const {
case kStorageOneDriveId: return "OneDrive";
case kStorageGoogleDriveId: return "GoogleDrive";
}
- assert(false); // Unhandled StorageIDs value
+ assert(false); // Unhandled StorageID value
return "";
}
diff --git a/backends/cloud/cloudmanager.h b/backends/cloud/cloudmanager.h
index 9f4882d772..48182dcde0 100644
--- a/backends/cloud/cloudmanager.h
+++ b/backends/cloud/cloudmanager.h
@@ -36,8 +36,8 @@ class CommandReceiver;
namespace Cloud {
-//that's actual indexes in CloudManager's array
-enum StorageIDs {
+// The actual indexes in CloudManager's array
+enum StorageID {
kStorageNoneId = 0,
kStorageDropboxId = 1,
kStorageOneDriveId = 2,
@@ -84,7 +84,7 @@ public:
* @note this method automatically saves the changes with ConfMan.
*
* @param storage Cloud::Storage to replace active storage with.
* @param index one of Cloud::StorageIDs enum values to indicate what storage type is replaced.
*/
void replaceStorage(Storage *storage, uint32 index);
@@ -84,7 +84,7 @@ public:
*
* @param storage Cloud::Storage to replace active storage with.
- * @param index one of Cloud::StorageIDs enum values to indicate what storage type is replaced.
+ * @param index one of Cloud::StorageID enum values to indicate what storage type is replaced.
*/
void replaceStorage(Storage *storage, uint32 index);